#!/usr/bin/env python
'''Module to easily send Python errors

USAGE:

>>> import reporter
>>> try:
...     float('r')
... except Exception, e:
...     reporter.mail('Error in code', e)
...

Using the UA mailserver only works when the script is run on the UA network.

Copyright (c) 2013 CLiPS. All rights reserved.
'''
__author__="Vincent Van Asch"
__date__="November 2013"
__version__="1.0"

import smtplib, time, quopri

# CONSTANTS ###############################
MAILSERVER = "smtp.uantwerpen.be"
SENDER = "Vincent Van Asch <vincent.vanasch@uantwerpen.be>"
RECIPIENT = "Vincent Van Asch <vincent.vanasch@uantwerpen.be>"


def exception_to_str(e):
    '''Takes an exception and returns a string version of it'''
    import sys, traceback
    info=sys.exc_info()
    
    try:
        error = ' '.join(traceback.format_exception(info[0],info[1],info[2]))
    except Exception:
        error = '%s: ARGS: %s' %(e.__class__.__name__, str(e.args))
    #print 'ERROR================\n', error, '\n======================='
    
    return error



def mail(subject, body, sender=SENDER, recipient=RECIPIENT, mailserver=MAILSERVER, html=False):
    '''Sends a mail
    
    subject   : string, the subject of the mail
    body      : string or exception, the contents of the mail (UTF8 encoded)
    sender    : string, the sender address
    recipient : string, the receiver address
    mailserver: string, the mail server IP
    html      : bool, if body is HTML text this should be set to True. 
    '''
    moment = time.strftime('%d %B %Y om %H:%M:%S', time.localtime(time.time()))
    
    if isinstance(body, Exception):
        body = exception_to_str(body)
    
    format = 'plain'
    if html:
        format = 'html'
        moment = '<br><br>'+moment
    
    message = """From: %s
To: %s
Subject: %s
MIME-Version: 1.0
Content-type: text/%s;charset=utf-8
Content-transfer-encoding: quoted-printable
     
%s

%s
""" % (sender, recipient, subject, format, quopri.encodestring(body), moment)

    p = smtplib.SMTP(mailserver)
    p.sendmail(sender, recipient, message)
    p.quit()